@@ -9,7 +9,8 @@
 
 class QSqlDatabase;
 
-namespace DbAccess {
+namespace DbAccess
+{
 QSqlDatabase database();
 }
 
