@@ -7,45 +7,38 @@
 #ifndef AKONADICONSOLE_UTILS_H_
 #define AKONADICONSOLE_UTILS_H_
 
-#include <QStringList>
 #include <QDateTime>
 #include <QStandardItem>
+#include <QStringList>
 
 #include <akonadi/private/protocol_p.h>
 
-template<typename T>
-typename std::enable_if<std::is_integral<T>::value, QString>::type
-toString(T num)
+template<typename T> typename std::enable_if<std::is_integral<T>::value, QString>::type toString(T num)
 {
     return QString::number(num);
 }
 
-inline
-QString toString(bool value)
+inline QString toString(bool value)
 {
     return value ? QStringLiteral("true") : QStringLiteral("false");
 }
 
-inline
-QString toString(const QDateTime &dt)
+inline QString toString(const QDateTime &dt)
 {
     return dt.toString(Qt::ISODate);
 }
 
-inline
-QString toString(const QString &str)
+inline QString toString(const QString &str)
 {
     return str;
 }
 
-inline
-QString toString(const QByteArray &ba)
+inline QString toString(const QByteArray &ba)
 {
     return QString::fromUtf8(ba);
 }
 
-inline
-QString toString(Akonadi::Tristate tristate)
+inline QString toString(Akonadi::Tristate tristate)
 {
     switch (tristate) {
     case Akonadi::Tristate::True:
@@ -58,8 +51,7 @@ QString toString(Akonadi::Tristate tristate)
     return {};
 }
 
-template<typename T, template<typename> class Container>
-QString toString(const Container<T> &set)
+template<typename T, template<typename> class Container> QString toString(const Container<T> &set)
 {
     QStringList rv;
     for (const auto &v : set) {
@@ -68,20 +60,18 @@ QString toString(const Container<T> &set)
     return rv.join(QLatin1String(", "));
 }
 
-inline
-void appendRow(QStandardItemModel *model, const QString &name, const QString &value)
+inline void appendRow(QStandardItemModel *model, const QString &name, const QString &value)
 {
     auto item = new QStandardItem(value);
     item->setToolTip(value);
-    model->appendRow({ new QStandardItem(name), item });
+    model->appendRow({new QStandardItem(name), item});
 }
 
-inline
-void appendRow(QStandardItem *parent, const QString &name, const QString &value)
+inline void appendRow(QStandardItem *parent, const QString &name, const QString &value)
 {
     auto item = new QStandardItem(value);
     item->setToolTip(value);
-    parent->appendRow({ new QStandardItem(name), item });
+    parent->appendRow({new QStandardItem(name), item});
 }
 
 #endif
